magneticalc.Metric_Widget.Metric_Widget

# ``magneticalc`.`Metric_Widget`.`Metric_Widget``

class documentation

`class Metric_Widget(QGroupBox2):`

Constructor: `Metric_Widget(gui)`

View In Hierarchy

Metric_Widget class.

Method | `__init__` | Populates the widget.
Method | `reload` | Reloads the widget.
Method | `set_metric` | Sets the metric. This will overwrite the currently set metric in the model. Any underscored parameter may be left set to None in order to load its default value.
Method | `update` | Updates the widget.
Method | `update_controls` | Updates the controls.
Method | `update_labels` | Updates the labels.
Class Variable | `Cool_Gradient_CSS` | Undocumented
Class Variable | `HSV_Gradient_CSS` | Undocumented
Class Variable | `ValuePrecision` | Undocumented
Instance Variable | `alpha_metric_combobox` | Undocumented
Instance Variable | `alpha_metric_limits_layout` | Undocumented
Instance Variable | `alpha_metric_limits_widget` | Undocumented
Instance Variable | `alpha_metric_max_label` | Undocumented
Instance Variable | `alpha_metric_min_label` | Undocumented
Instance Variable | `color_metric_combobox` | Undocumented
Instance Variable | `color_metric_limits_layout` | Undocumented
Instance Variable | `color_metric_limits_widget` | Undocumented
Instance Variable | `color_metric_max_label` | Undocumented
Instance Variable | `color_metric_min_label` | Undocumented
Instance Variable | `gui` | Undocumented

Inherited from `QGroupBox2`:

Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted` (via `QGroupBox2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`

Populates the widget.

Parameters
gui: `GUI` | GUI

def reload(self):

Reloads the widget.

def set_metric(self, _color_preset_: `dict | None` = None, _alpha_preset_: `dict | None` = None, invalidate: `bool` = True, recalculate: `bool` = True, update_labels: `bool` = True):

Sets the metric. This will overwrite the currently set metric in the model. Any underscored parameter may be left set to None in order to load its default value.

Parameters
_color_preset_: `dict | None` | Color metric preset (parameters, see Metric module)
_alpha_preset_: `dict | None` | Alpha metric preset (parameters, see Metric module)
invalidate: `bool` | Enable to invalidate this model hierarchy level
recalculate: `bool` | Enable to trigger final recalculation
update_labels: `bool` | Enable to update metric labels

def update(self):

Updates the widget.

def update_controls(self):

Updates the controls.

def update_labels(self):

Updates the labels.

Cool_Gradient_CSS: `str` =

Undocumented

HSV_Gradient_CSS: `str` =

Undocumented

ValuePrecision: `int` =

Undocumented

alpha_metric_combobox =

Undocumented

alpha_metric_limits_layout =

Undocumented

alpha_metric_limits_widget =

Undocumented

alpha_metric_max_label =

Undocumented

alpha_metric_min_label =

Undocumented

color_metric_combobox =

Undocumented

color_metric_limits_layout =

Undocumented

color_metric_limits_widget =

Undocumented

color_metric_max_label =

Undocumented

color_metric_min_label =

Undocumented

gui =

Undocumented